@@ -2,6 +2,7 @@
 import os
 #import proj as p
 try:
+  import cli
   import time
   import sys
   import getopt
@@ -26,7 +27,7 @@ import os
 
 
 pos = ["name","run","version","dependencies","modules","projects","authors"]
-class main:
+class mainz:
   def openproj():
     with open(f"{os.getcwd()}/build.proj") as w:
       content = w.read()
@@ -265,6 +266,7 @@ def run(command):
     subprocess.check_output(command,shell=True)
 
 def main():
+
     advanced = ["help","sendargs =","runfunc =","build","install","proj ="]
 
 
@@ -289,7 +291,7 @@ def main():
           send_help()
 
         if opt in ["--proj"]:
-          main.parseproj(opt,arg,args)
+          mainz.parseproj(opt,arg,args)
           
         if opt in ["--sendargs"]:
           return {"x":"t","args":sys.argv}
@@ -310,11 +312,11 @@ def main():
 def default(x):
   if x != None:
     if x["x"] == "t":
-      file = f"{os.getcwd}/Buildfile"
+      file = f"Buildfile"
       try:
         file = x["file"]
       except KeyError:
-        file = f"{os.getcwd}/Buildfile"
+        file = f"Buildfile"
 
       args = x["args"]
       argz = ""
@@ -328,11 +330,13 @@ def default(x):
       files = []
       for filex in os.listdir(os.getcwd()):
         files.append(filex)
+
       if file in files:
         xylo = False
         tex = ""
         line = 0
         function = ""
+        
         printc(CVIOLET,"Running build ...")
         f = open(f"{os.getcwd()}/{file}", "r")
         try:
@@ -629,7 +633,10 @@ def default(x):
         printc(CVIOLET,"Running make ...")
         run("make")
 
+r = True 
+
+def launch():
+  x = main()
+  default(x)
+
 
-if __name__ == "__main__":
-    x = main()
-    default(x)
\ No newline at end of file
